@@ -4,7 +4,7 @@ from policyengine_canada.model_api import *
 class bc_family_benefit(Variable):
     value_type = float
     entity = Household
-    label = "British Columbia family benefit second reduction"
+    label = "British Columbia family benefit"
     unit = CAD
     definition_period = YEAR
     defined_for = ProvinceCode.BC
